Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsGraphQLSDL ¶
func ParseLenient ¶
ParseLenient parses an OpenAPI spec, skipping validation errors from broken $refs. It logs warnings to stderr for any issues found but continues parsing.
func SetMaxEndpointsPerResource ¶
func SetMaxEndpointsPerResource(n int)
SetMaxEndpointsPerResource overrides the default limit and disables auto-calibration. When not called, the parser auto-calibrates the limit from the spec so well-formed specs never have endpoints silently skipped.
func SetMaxResources ¶
func SetMaxResources(n int)
SetMaxResources overrides the default resource limit. When not called, the parser uses a default of 500 which accommodates all known APIs.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.